@@ -685,7 +685,12 @@ rulecreate_call_create_funcs(const int debuglvl, /*@null@*/RuleSet *ruleset, str
     else if(create->ruletype == RT_MASQ)
     {
         if (create->option.random == TRUE) {
-            snprintf(rule->random, sizeof(rule->random), "--random");
+            if (conf.check_iptcaps == FALSE || iptcap->target_nat_random == TRUE) {
+                snprintf(rule->random, sizeof(rule->random), "--random");
+            } else {
+                (void)vrprint.debug(__FUNC__, "MASQ random option not supported: iptcap->target_nat_random %s.",
+                        iptcap->target_nat_random ? "TRUE" : "FALSE");
+            }
         }
 
         if(create_rule_masq(debuglvl, ruleset, rule, create, iptcap) < 0)
@@ -711,7 +716,12 @@ rulecreate_call_create_funcs(const int debuglvl, /*@null@*/RuleSet *ruleset, str
         }
 
         if (create->option.random == TRUE) {
-            snprintf(rule->random, sizeof(rule->random), "--random");
+            if (conf.check_iptcaps == FALSE || iptcap->target_nat_random == TRUE) {
+                snprintf(rule->random, sizeof(rule->random), "--random");
+            } else {
+                (void)vrprint.debug(__FUNC__, "SNAT random option not supported: iptcap->target_nat_random %s.",
+                        iptcap->target_nat_random ? "TRUE" : "FALSE");
+            }
         }
 
         if(create_rule_snat(debuglvl, ruleset, rule, create, iptcap) < 0)
@@ -737,7 +747,12 @@ rulecreate_call_create_funcs(const int debuglvl, /*@null@*/RuleSet *ruleset, str
         }
 
         if (create->option.random == TRUE) {
-            snprintf(rule->random, sizeof(rule->random), "--random");
+            if (conf.check_iptcaps == FALSE || iptcap->target_nat_random == TRUE) {
+                snprintf(rule->random, sizeof(rule->random), "--random");
+            } else {
+                (void)vrprint.debug(__FUNC__, "PORTFW random option not supported: iptcap->target_nat_random %s.",
+                        iptcap->target_nat_random ? "TRUE" : "FALSE");
+            }
         }
 
         if(create_rule_portfw(debuglvl, ruleset, rule, create, iptcap) < 0)
@@ -770,7 +785,12 @@ rulecreate_call_create_funcs(const int debuglvl, /*@null@*/RuleSet *ruleset, str
         }
 
         if (create->option.random == TRUE) {
-            snprintf(rule->random, sizeof(rule->random), "--random");
+            if (conf.check_iptcaps == FALSE || iptcap->target_nat_random == TRUE) {
+                snprintf(rule->random, sizeof(rule->random), "--random");
+            } else {
+                (void)vrprint.debug(__FUNC__, "DNAT random option not supported: iptcap->target_nat_random %s.",
+                        iptcap->target_nat_random ? "TRUE" : "FALSE");
+            }
         }
 
         if(create_rule_dnat(debuglvl, ruleset, rule, create, iptcap) < 0)
@@ -795,7 +815,12 @@ rulecreate_call_create_funcs(const int debuglvl, /*@null@*/RuleSet *ruleset, str
         }
 
         if (create->option.random == TRUE) {
-            snprintf(rule->random, sizeof(rule->random), "--random");
+            if (conf.check_iptcaps == FALSE || iptcap->target_nat_random == TRUE) {
+                snprintf(rule->random, sizeof(rule->random), "--random");
+            } else {
+                (void)vrprint.debug(__FUNC__, "BOUNCE random option not supported: iptcap->target_nat_random %s.",
+                        iptcap->target_nat_random ? "TRUE" : "FALSE");
+            }
         }
 
         if(create_rule_bounce(debuglvl, ruleset, rule, create, iptcap) < 0)
@@ -1462,7 +1487,7 @@ rulecreate_dst_iface_loop (const int debuglvl, struct vuurmuur_config *cnf,
             retval = rulecreate_service_loop(debuglvl, ruleset, rule, create, iptcap);
 
             /* shaping rules */
-            if (shaping_shape_outgoing_rule(debuglvl, &create->option) == 1) {
+            if (libvuurmuur_is_shape_outgoing_rule(debuglvl, &create->option) == 1) {
                 /* at this point we can create the tc rules */
                 retval = shaping_shape_create_rule(debuglvl, cnf, interfaces, rule, ruleset,
                     rule->to_if_ptr, rule->from_if_ptr, rule->shape_class_out,
@@ -1473,7 +1498,7 @@ rulecreate_dst_iface_loop (const int debuglvl, struct vuurmuur_config *cnf,
                     return(retval);
                 }
             }
-            if (shaping_shape_incoming_rule(debuglvl, &create->option) == 1) {
+            if (libvuurmuur_is_shape_incoming_rule(debuglvl, &create->option) == 1) {
                 /* at this point we can create the tc rules */
                 retval = shaping_shape_create_rule(debuglvl, cnf, interfaces, rule, ruleset,
                     rule->from_if_ptr, rule->to_if_ptr, rule->shape_class_in,
@@ -1528,7 +1553,7 @@ rulecreate_dst_iface_loop (const int debuglvl, struct vuurmuur_config *cnf,
             retval = rulecreate_service_loop(debuglvl, ruleset, rule, create, iptcap);
 
             /* shaping rules */
-            if (shaping_shape_outgoing_rule(debuglvl, &create->option) == 1) {
+            if (libvuurmuur_is_shape_outgoing_rule(debuglvl, &create->option) == 1) {
                 /* at this point we can create the tc rules */
                 retval = shaping_shape_create_rule(debuglvl, cnf, interfaces, rule, ruleset,
                     rule->to_if_ptr, rule->from_if_ptr, rule->shape_class_out,
@@ -1539,7 +1564,7 @@ rulecreate_dst_iface_loop (const int debuglvl, struct vuurmuur_config *cnf,
                     return(retval);
                 }
             }
-            if (shaping_shape_incoming_rule(debuglvl, &create->option) == 1) {
+            if (libvuurmuur_is_shape_incoming_rule(debuglvl, &create->option) == 1) {
                 /* at this point we can create the tc rules */
                 retval = shaping_shape_create_rule(debuglvl, cnf, interfaces, rule, ruleset,
                     rule->from_if_ptr, rule->to_if_ptr, rule->shape_class_in,
@@ -1624,7 +1649,7 @@ rulecreate_dst_iface_loop (const int debuglvl, struct vuurmuur_config *cnf,
                 }
 
                 /* shaping rules */
-                if (shaping_shape_outgoing_rule(debuglvl, &create->option) == 1) {
+                if (libvuurmuur_is_shape_outgoing_rule(debuglvl, &create->option) == 1) {
                     /* at this point we can create the tc rules */
                     retval = shaping_shape_create_rule(debuglvl, cnf, interfaces, rule, ruleset,
                         rule->to_if_ptr, rule->from_if_ptr, rule->shape_class_out,
@@ -1635,7 +1660,7 @@ rulecreate_dst_iface_loop (const int debuglvl, struct vuurmuur_config *cnf,
                         return(retval);
                     }
                 }
-                if (shaping_shape_incoming_rule(debuglvl, &create->option) == 1) {
+                if (libvuurmuur_is_shape_incoming_rule(debuglvl, &create->option) == 1) {
                     /* at this point we can create the tc rules */
                     retval = shaping_shape_create_rule(debuglvl, cnf, interfaces, rule, ruleset,
                         rule->from_if_ptr, rule->to_if_ptr, rule->shape_class_in,
@@ -1900,7 +1925,7 @@ create_rule(const int debuglvl, struct vuurmuur_config *cnf,
         (void)strlcpy(rule->helper, create->service->helper, sizeof(rule->helper));
 
     /* SHAPING PREPARATION */
-    if (shaping_shape_rule(debuglvl, &create->option) == 1) {
+    if (libvuurmuur_is_shape_rule(debuglvl, &create->option) == 1) {
         rule->shape_class_out = interfaces->shape_handle;
         interfaces->shape_handle++;
         rule->shape_class_in = interfaces->shape_handle;
