@@ -41,63 +41,11 @@ shaping_convert_rate(const int debuglvl, u_int32_t rate, char *unit) {
     return(kbit_rate);
 }
 
-int
-shaping_shape_rule(const int debuglvl, /*@null@*/struct options *opt) {
-    if (opt != NULL && 
-        (opt->bw_in_min > 0 ||
-        opt->bw_in_max > 0 ||
-        opt->bw_out_min > 0 ||
-        opt->bw_out_max > 0 ||
-        opt->prio > 0))
-    {
-        return(1);
-    }
-    
-    return(0);
-}
-int
-shaping_shape_incoming_rule(const int debuglvl, /*@null@*/struct options *opt) {
-    if (opt != NULL && 
-        (opt->bw_in_min > 0 ||
-        opt->bw_in_max > 0 ||
-        opt->prio > 0))
-    {
-        return(1);
-    }
-    
-    return(0);
-}
-int
-shaping_shape_outgoing_rule(const int debuglvl, /*@null@*/struct options *opt) {
-    if (opt != NULL && 
-        (opt->bw_out_min > 0 ||
-        opt->bw_out_max > 0 ||
-        opt->prio > 0))
-    {
-        return(1);
-    }
-    
-    return(0);
-}
-
-int
-shaping_shape_interface(const int debuglvl, /*@null@*/InterfaceData *iface_ptr) {
-    if (iface_ptr != NULL && 
-        iface_ptr->shape == TRUE &&
-        iface_ptr->device_virtual == FALSE &&
-        (conf.bash_out || iface_ptr->up == TRUE))
-    {
-        return(1);
-    }
-
-    return(0);
-}
-
-/*  structure for storing an iptables rule in the queue.
+/* structure for storing an iptables rule in the queue.
  *
- *      These are the 'same':
- *  /sbin/tc class add dev eth2 parent 4:2 classid 4:12 htb rate 8192kbit ceil 9216kbit prio 1
- *      /sbin/tc class add dev eth2 parent 4:3 classid 4:12 htb rate 8192kbit ceil 9216kbit prio 1
+ * These are the 'same':
+ * /sbin/tc class add dev eth2 parent 4:2 classid 4:12 htb rate 8192kbit ceil 9216kbit prio 1
+ * /sbin/tc class add dev eth2 parent 4:3 classid 4:12 htb rate 8192kbit ceil 9216kbit prio 1
  */
 typedef struct
 {
@@ -333,7 +281,7 @@ shaping_setup_interface_classes (const int debuglvl, struct vuurmuur_config *cnf
         inner_iface_ptr = d_node->data;
 
         if (iface_ptr != inner_iface_ptr && /* don't add a class for yourself */
-            shaping_shape_interface(debuglvl, inner_iface_ptr) == 1)
+            libvuurmuur_is_shape_interface(debuglvl, inner_iface_ptr) == 1)
         {
             rate = shaping_convert_rate(debuglvl, inner_iface_ptr->bw_in, inner_iface_ptr->bw_in_unit);
             if (iface_rate < rate)
@@ -370,7 +318,7 @@ shaping_setup_roots (const int debuglvl, struct vuurmuur_config *cnf, Interfaces
         iface_ptr = d_node->data;
         (void)vrprint.debug(__FUNC__, "interface %s", iface_ptr->name);
 
-        if (shaping_shape_interface(debuglvl, iface_ptr) == 1)
+        if (libvuurmuur_is_shape_interface(debuglvl, iface_ptr) == 1)
         {
             iface_ptr->shape_handle = handle;
             handle++;
@@ -383,7 +331,7 @@ shaping_setup_roots (const int debuglvl, struct vuurmuur_config *cnf, Interfaces
         iface_ptr = d_node->data;
         (void)vrprint.debug(__FUNC__, "interface %s", iface_ptr->name);
 
-        if (shaping_shape_interface(debuglvl, iface_ptr) == 1)
+        if (libvuurmuur_is_shape_interface(debuglvl, iface_ptr) == 1)
         {
             snprintf(cmd, sizeof(cmd), "%s qdisc add dev %s root handle %u: htb default %u",
                 cnf->tc_location, iface_ptr->device, iface_ptr->shape_handle, handle);
@@ -508,7 +456,7 @@ shaping_determine_minimal_default_rates(const int debuglvl, Interfaces *interfac
     for (d_node_iface = interfaces->list.top; d_node_iface != NULL; d_node_iface = d_node_iface->next) {
         iface_ptr = d_node_iface->data;
 
-        if (shaping_shape_interface(debuglvl, iface_ptr) == 1)
+        if (libvuurmuur_is_shape_interface(debuglvl, iface_ptr) == 1)
         {
             rate = shaping_convert_rate(debuglvl, iface_ptr->bw_out, iface_ptr->bw_out_unit);
 
@@ -553,7 +501,7 @@ shaping_create_default_rules(const int debuglvl, struct vuurmuur_config *cnf, In
     for (d_node = interfaces->list.top; d_node != NULL; d_node = d_node->next) {
         iface_ptr = d_node->data;
 
-        if (shaping_shape_interface(debuglvl, iface_ptr) == 1)
+        if (libvuurmuur_is_shape_interface(debuglvl, iface_ptr) == 1)
         {
             rate = shaping_convert_rate(debuglvl, iface_ptr->bw_out, iface_ptr->bw_out_unit);
 
@@ -596,13 +544,16 @@ shaping_shape_create_rule(const int debuglvl, struct vuurmuur_config *cnf,
     char        cmd[MAX_PIPE_COMMAND] = "";
     u_int16_t   class_handle = 1;
 
-    if (shaping_shape_interface(debuglvl, shape_iface_ptr) == 0)
+    if (strcmp(cnf->tc_location,"") == 0)
+        return(0);
+
+    if (libvuurmuur_is_shape_interface(debuglvl, shape_iface_ptr) == 0)
         return(0);
 
     (void)vrprint.debug(__FUNC__, "shape on interface %s (handle %u)",
         shape_iface_ptr->name, shape_iface_ptr->shape_handle);
 
-    if (shaping_shape_interface(debuglvl, class_iface_ptr) == 1) {
+    if (libvuurmuur_is_shape_interface(debuglvl, class_iface_ptr) == 1) {
         class_handle = class_iface_ptr->shape_handle;
 
         (void)vrprint.debug(__FUNC__, "class of interface %s (handle %u)",
